Arguments
file
the filename of a spreadsheet data set from which to import
the data records.
FinCenter
a character with the the location of the financial center
named as "continent/city".
header
a logical value indicating whether the file contains the
names of the variables as its first line. If missing, the
value is determined from the file format: 'header' is set to
'TRUE' if and only if the first row contains one fewer
format
a character string with the format in POSIX notation specifying
the timestamp format. Note, the format has not to be specified
if the first column in the file has the timestamp format
specifyer, e.g. "%Y-%m-%d" for the short ISO 86
sep
the field seperator used in the spreadsheet file to separate
columns. By default ";". Note, if sep=";" is specified,
and reading the series fails, then the reading is automatically
repeated with sep=","
zone
the time zone or financial center where the data were recorded.
By default zone="" which is short for GMT.
...
Additional arguments passed to read.table() function which
is used to read the file.