The function turns determines the number and the position of
extrema (turning points, either peaks or pits) in a regular time series.
The function turnsStats calculates the quantity of information
associated to the observations in this series, according to Kendall's
information theory.
The functions are borrowed from the contributed R package pastecs
and made ready for working together with univariate timeSeries
objects. You need not to load the R package pastecs, the code parts
we need here are builtin in the timeSeries package.
We have renamed the function turnpoints to turns to
distinguish between the original function in the contributed R package
pastecs and our Rmetrics function wrapper.
For further details please consult the help page from the contributed R
package pastecs.